@@ -1,4 +1,4 @@
-/* $Id: rapi.h,v 1.34 2003/07/03 11:24:46 twogood Exp $ */
+/* $Id: rapi.h,v 1.40 2005/01/14 21:49:18 twogood Exp $ */
 #ifndef __rapi_h__
 #define __rapi_h__
 
@@ -28,6 +28,59 @@ extern "C"
 {
 #endif
 
+/*
+ * SynCE support for switching between multiple devices
+ *
+ * Example code for two devices follows!
+ *
+ * It shows two different ways to get a RapiConnection object.
+ *
+ *   RapiConnection* a = rapi_connection_from_path("/home/david/.synce/a");
+ *   rapi_connection_select(a);
+ *   CeRapiInit()
+ *
+ *   SynceInfo* info_b = synce_info_new("/home/david/.synce/b");
+ *   RapiConnection* b = rapi_connection_from_info(info_b);
+ *   rapi_connection_select(b);
+ *   CeRapiInit()
+ *
+ *   rapi_connection_select(a);
+ *   ...some RAPI calls to device A...
+ *
+ *   rapi_connection_select(b);
+ *   ...some RAPI calls to device B...
+ *
+ *   rapi_connection_select(a);
+ *   CeRapiUninit();
+ *   rapi_connection_destroy(a);
+ *   
+ *   rapi_connection_select(b);
+ *   CeRapiUninit();
+ *   rapi_connection_destroy(b);
+ */
+
+typedef struct _RapiConnection RapiConnection;
+
+/** 
+ * Create a connection - use this before you call CeRapiInit() 
+ *
+ * @path Parameter sent to synce_info_new() in libsynce/lib/info.c
+ */
+RapiConnection* rapi_connection_from_path(const char* path);
+
+/** 
+ * Create a connection - low-level version
+ */
+RapiConnection* rapi_connection_from_info(SynceInfo* info);
+
+/** Select what connection is used for RAPI calls */
+void rapi_connection_select(RapiConnection* connection);
+
+/** Destroy connection object - use this after CeRapiUninit() */
+void rapi_connection_destroy(RapiConnection* connection);
+
+ 
+
 /*
  * Main RAPI functions
  */
@@ -43,6 +96,8 @@ HRESULT CeRapiInit(void);
 
 STDAPI CeRapiUninit(void);
 
+HRESULT CeRapiGetError(void);
+
 #endif /* SWIG */
 
 
@@ -387,7 +442,15 @@ CEOID CeWriteRecordProps(
 		HANDLE hDbase, 
 		CEOID oidRecord, 
 		WORD cPropID, 
-		CEPROPVAL *rgPropVal );
+		CEPROPVAL *rgPropVal);
+
+BOOL CeDeleteRecord(
+    HANDLE hDatabase, 
+    CEOID oidRecord);
+
+BOOL CeSetDatabaseInfo( 
+    CEOID oidDbase,
+    CEDBASEINFO* pNewInfo);
 
 #endif /* SWIG */
 
@@ -635,8 +698,8 @@ typedef struct _SYSTEM_INFO {
 	WORD wProcessorArchitecture;
 	WORD wReserved;
 	DWORD dwPageSize;
-	LPVOID lpMinimumApplicationAddress;
-	LPVOID lpMaximumApplicationAddress;
+	ULONG lpMinimumApplicationAddress;
+	ULONG lpMaximumApplicationAddress;
 	DWORD dwActiveProcessorMask;
 	DWORD dwNumberOfProcessors;
 	DWORD dwProcessorType;
@@ -714,6 +777,11 @@ HRESULT CeProcessConfig(LPCWSTR config, DWORD flags, LPWSTR* reply);
 
 HRESULT CeStartReplication( void );
 
+#define SYSMEM_CHANGED        0
+#define SYSMEM_MUSTREBOOT     1
+#define SYSMEM_REBOOTPENDING  2
+#define SYSMEM_FAILED         3
+
 BOOL CeGetSystemMemoryDivision(
     LPDWORD lpdwStoragePages, 
     LPDWORD lpdwRamPages, 
@@ -722,6 +790,11 @@ BOOL CeGetSystemMemoryDivision(
 DWORD CeSetSystemMemoryDivision(
     DWORD dwStoragePages);
 
+BOOL CeRegCopyFile(LPCWSTR filename);
+BOOL CeRegRestoreFile(LPCWSTR filename);
+
+BOOL CeKillAllApps();
+
 #endif /* SWIG */
 
 /*
