@@ -1,4 +1,4 @@
-/* $Id: rapi_context.h,v 1.3 2003/04/05 14:44:54 twogood Exp $ */
+/* $Id: rapi_context.h,v 1.6 2005/01/14 21:49:18 twogood Exp $ */
 #ifndef __rapi_context_h__
 #define __rapi_context_h__
 
@@ -13,7 +13,9 @@ typedef struct _RapiContext
 	uint32_t result_1;
 	uint32_t result_2;
 	uint32_t last_error;
+  uint32_t rapi_error;
 	bool is_initialized;
+  SynceInfo* info;
 } RapiContext;
 
 /**
@@ -21,6 +23,11 @@ typedef struct _RapiContext
  */
 RapiContext* rapi_context_current();
 
+/**
+ * Set current RapiContext
+ */
+void rapi_context_set(RapiContext* context);
+
 /**
  * Create new context
  */
